==> opensi-9.9.0-64.tar.gz: content/opensi/compta/user/main.js <==
/**********************************************************************************************/
/* OpenSi : Logiciel SaaS de gestion commerciale et comptabilit spcialis dans l'e-commerce */
/* Copyright (c) - Tous droits rservs - SAS Speedinfo Evolution                             */
/**********************************************************************************************/

jsLoader.loadSubScript("chrome://opensi/content/libs/profil.js");
jsLoader.loadSubScript("chrome://opensi/content/libs/config.js");


var mainProfil = null;
var mainConfig = null;
var sessionId;


function init() {
	try {

		window.maximize();

  	var page = "chrome://opensi/content/compta/user/menu.xul?"+ cookie();
  	document.getElementById("contenu").setAttribute("src",page);
    document.getElementById("login").value = ParamValeur("Utilisateur");

		if (ParamValeur("VTest")=="true") {
			document.getElementById("imgLogo").setAttribute("src", "chrome://opensi/content/design/logo-test-appli.jpg");
		}

		document.getElementById("date_courante").value = getDateCourante();

		sessionId = ParamValeur("S_");

	} catch (e) {
    recup_erreur(e);
  }
}


function getProfil() {

	if (mainProfil==null) {
		mainProfil = new Profil();
	}

	return mainProfil;
}


function resetProfil() {

	mainProfil = null;
}


function getConfig() {

	if (mainConfig==null) {
		mainConfig = new Config();
	}

	return mainConfig;
}


function resetConfig() {

	mainConfig = null;
}


function getSessionId() {

	return sessionId;
}

==> opensi-9.10.0-32.tar.gz: content/opensi/compta/user/main.js <==
/**********************************************************************************************/
/* OpenSi : Logiciel SaaS de gestion commerciale et comptabilit spcialis dans l'e-commerce */
/* Copyright (c) - Tous droits rservs - SAS Speedinfo Evolution                             */
/**********************************************************************************************/

jsLoader.loadSubScript("chrome://opensi/content/libs/profil.js");
jsLoader.loadSubScript("chrome://opensi/content/libs/config.js");


var mainProfil = null;
var mainConfig = null;
var sessionId;


function init() {
	try {

		window.maximize();

  	var page = "chrome://opensi/content/compta/user/menu.xul?"+ cookie();
  	document.getElementById("contenu").setAttribute("src",page);
    document.getElementById("login").value = ParamValeur("Utilisateur");

		if (ParamValeur("VTest")=="true") {
			document.getElementById("imgLogo").setAttribute("src", "chrome://opensi/content/design/logo-test-appli.svg");
		}

		document.getElementById("date_courante").value = getDateCourante();

		sessionId = ParamValeur("S_");

	} catch (e) {
    recup_erreur(e);
  }
}


function getProfil() {

	if (mainProfil==null) {
		mainProfil = new Profil();
	}

	return mainProfil;
}


function resetProfil() {

	mainProfil = null;
}


function getConfig() {

	if (mainConfig==null) {
		mainConfig = new Config();
	}

	return mainConfig;
}


function resetConfig() {

	mainConfig = null;
}


function getSessionId() {

	return sessionId;
}
